@@ -9,13 +9,19 @@ from evident.diversity_handler import (AlphaDiversityHandler,
                                        BetaDiversityHandler)
 import evident._exceptions as exc
 
+na_values = ["not applicable"]
+
 
 class TestAlphaDiv:
     def test_init_alpha_div_handler(self):
         fname = os.path.join(os.path.dirname(__file__), "data/metadata.tsv")
-        df = pd.read_table(fname, sep="\t", index_col=0)
+        df = pd.read_table(fname, sep="\t", index_col=0, na_values=na_values)
+        exp_cols = [
+            "cd_behavior", "cd_location", "cd_resection", "ibd_subtype",
+            "perianal_disease", "sex", "classification"
+        ]
         a = AlphaDiversityHandler(df["faith_pd"], df)
-        assert a.metadata.shape == (220, 40)
+        assert a.metadata.shape == (220, len(exp_cols))
         assert a.data.shape == (220, )
 
     def test_subset_alpha_values(self, alpha_mock):
@@ -30,16 +36,47 @@ class TestAlphaDiv:
         md = alpha_mock.metadata
         assert (md.index == alpha_mock.samples).all()
 
+    def test_alpha_wrong_data(self, alpha_mock):
+        data = alpha_mock.data.to_frame()
+
+        with pytest.raises(ValueError) as exc_info:
+            AlphaDiversityHandler(data, alpha_mock.metadata)
+
+        exp_err_msg = "data must be of type pandas.Series"
+        assert str(exc_info.value) == exp_err_msg
+
+    def test_alpha_data_nan(self, alpha_mock):
+        data = alpha_mock.data
+        data[0] = np.nan
+        data[-1] = np.nan
+        with pytest.warns(UserWarning) as warn_info:
+            AlphaDiversityHandler(data, alpha_mock.metadata)
+
+        warn_msg_1 = warn_info[0].message.args[0]
+        warn_msg_2 = warn_info[1].message.args[0]
+
+        exp_warn_msg_1 = "data has 2 NAs. Dropping these values."
+        exp_warn_msg_2 = (
+            "Data and metadata do not have the same sample IDs. Using "
+            "218 samples common to both."
+        )
+        assert exp_warn_msg_1 == warn_msg_1
+        assert exp_warn_msg_2 == warn_msg_2
+
 
 class TestBetaDiv:
     def test_init_beta_div_handler(self):
         fname = os.path.join(os.path.dirname(__file__), "data/metadata.tsv")
-        df = pd.read_table(fname, sep="\t", index_col=0)
+        df = pd.read_table(fname, sep="\t", index_col=0, na_values=na_values)
+        exp_cols = [
+            "cd_behavior", "cd_location", "cd_resection", "ibd_subtype",
+            "perianal_disease", "sex", "classification"
+        ]
         dm_file = os.path.join(os.path.dirname(__file__),
                                "data/distance_matrix.lsmat.gz")
         dm = DistanceMatrix.read(dm_file)
         b = BetaDiversityHandler(dm, df)
-        assert b.metadata.shape == (220, 40)
+        assert b.metadata.shape == (220, len(exp_cols))
         assert b.data.shape == (220, 220)
 
     def test_subset_beta_values(self, beta_mock):
@@ -54,6 +91,15 @@ class TestBetaDiv:
         md = beta_mock.metadata
         assert (md.index == beta_mock.samples).all()
 
+    def test_beta_wrong_data(self, beta_mock):
+        data = beta_mock.data.to_data_frame()
+
+        with pytest.raises(ValueError) as exc_info:
+            BetaDiversityHandler(data, beta_mock.metadata)
+
+        exp_err_msg = "data must be of type skbio.DistanceMatrix"
+        assert str(exc_info.value) == exp_err_msg
+
 
 class TestPower:
     def test_alpha_power_power_t(self, alpha_mock):
@@ -123,31 +169,6 @@ class TestPower:
         )
         assert str(exc_info.value) == exp_err_msg
 
-    def test_alpha_power_non_categorical(self, alpha_mock):
-        with pytest.raises(exc.NonCategoricalColumnError) as exc_info:
-            alpha_mock.power_analysis(
-                "year_diagnosed",
-                alpha=0.05,
-                power=0.8
-            )
-        exp_err_msg = (
-            "Column must be categorical (dtype object). 'year_diagnosed' "
-            "is of type int64."
-        )
-        assert str(exc_info.value) == exp_err_msg
-
-    def test_alpha_power_only_one_cat(self, alpha_mock):
-        with pytest.raises(exc.OnlyOneCategoryError) as exc_info:
-            alpha_mock.power_analysis(
-                "env_biome",
-                alpha=0.05,
-                power=0.8
-            )
-        exp_err_msg = (
-            "Column env_biome has only one value: 'urban biome'."
-        )
-        assert str(exc_info.value) == exp_err_msg
-
     def test_alpha_power_f(self, alpha_mock, monkeypatch):
         # Monkey patch Cohen's f calculation directly in diversity_handler
         #     instead of in _utils. Doesn't really make sense that it has
@@ -179,23 +200,6 @@ class TestPower:
 
 
 class TestEffectSize:
-    def test_non_categorical(self, alpha_mock):
-        with pytest.raises(exc.NonCategoricalColumnError) as exc_info:
-            alpha_mock.calculate_effect_size("year_diagnosed")
-        exp_err_msg = (
-            "Column must be categorical (dtype object). 'year_diagnosed' "
-            "is of type int64."
-        )
-        assert str(exc_info.value) == exp_err_msg
-
-    def test_only_one_category(self, alpha_mock):
-        with pytest.raises(exc.OnlyOneCategoryError) as exc_info:
-            alpha_mock.calculate_effect_size("env_biome")
-        exp_err_msg = (
-            "Column env_biome has only one value: 'urban biome'."
-        )
-        assert str(exc_info.value) == exp_err_msg
-
     def test_difference(self, alpha_mock):
         calc_effect_size = alpha_mock.calculate_effect_size(
             "classification",
